MethodChannelFlutterSaver class

Default FlutterSaverPlatform implementation using MethodChannel.

This class exists as the default instance for the platform interface. Actual save/download logic is handled by FlutterSaver in src/flutter_saver_base.dart, which dispatches to platform-specific classes (AndroidChannel, IosChannel, MacosChannel, WindowsSaver, WebSaver) without going through this channel.

Inheritance

Constructors

MethodChannelFlutterSaver()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited