FlutterSaverPlatform class abstract

Platform interface for flutter_saver.

Concrete implementations (Web shim) extend this class. The main logic lives in FlutterSaver (src/flutter_saver_base.dart) which dispatches directly to platform-specific implementations without going through this interface for Android / iOS / macOS / Windows.

Inheritance
  • Object
  • PlatformInterface
  • FlutterSaverPlatform
Implementers

Constructors

FlutterSaverPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterSaverPlatform
getter/setter pair